# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: groups.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2
from . import discussions_pb2 as discussions__pb2
from . import events_pb2 as events__pb2
from . import pages_pb2 as pages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='groups.proto',
  package='org.couchers.api.groups',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0cgroups.proto\x12\x17org.couchers.api.groups\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\x1a\x11\x64iscussions.proto\x1a\x0c\x65vents.proto\x1a\x0bpages.proto\"X\n\x0f\x43ommunityParent\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"P\n\x0bGroupParent\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"\x88\x01\n\x06Parent\x12=\n\tcommunity\x18\x01 \x01(\x0b\x32(.org.couchers.api.groups.CommunityParentH\x00\x12\x35\n\x05group\x18\x02 \x01(\x0b\x32$.org.couchers.api.groups.GroupParentH\x00\x42\x08\n\x06parent\"\xba\x02\n\x05Group\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12+\n\x07\x63reated\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x07parents\x18\x06 \x03(\x0b\x32\x1f.org.couchers.api.groups.Parent\x12/\n\tmain_page\x18\x07 \x01(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x0e\n\x06member\x18\x08 \x01(\x08\x12\r\n\x05\x61\x64min\x18\t \x01(\x08\x12\x14\n\x0cmember_count\x18\n \x01(\r\x12\x13\n\x0b\x61\x64min_count\x18\x0b \x01(\r\x12\x14\n\x0c\x63\x61n_moderate\x18\x0c \x01(\x08\"\x1f\n\x0bGetGroupReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\"H\n\rListAdminsReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"@\n\rListAdminsRes\x12\x16\n\x0e\x61\x64min_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"I\n\x0eListMembersReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"B\n\x0eListMembersRes\x12\x17\n\x0fmember_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"H\n\rListPlacesReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"V\n\rListPlacesRes\x12,\n\x06places\x18\x01 \x03(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"H\n\rListGuidesReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"V\n\rListGuidesRes\x12,\n\x06guides\x18\x01 \x03(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"V\n\rListEventsReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x0c\n\x04past\x18\x04 \x01(\x08\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"X\n\rListEventsRes\x12.\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"M\n\x12ListDiscussionsReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"l\n\x12ListDiscussionsRes\x12=\n\x0b\x64iscussions\x18\x01 \x03(\x0b\x32(.org.couchers.api.discussions.Discussion\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\" \n\x0cJoinGroupReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\"!\n\rLeaveGroupReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\"K\n\x11ListUserGroupsReq\x12\x0f\n\x07user_id\x18\x01 \x01(\r\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"\\\n\x11ListUserGroupsRes\x12.\n\x06groups\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.groups.Group\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xbe\x07\n\x06Groups\x12R\n\x08GetGroup\x12$.org.couchers.api.groups.GetGroupReq\x1a\x1e.org.couchers.api.groups.Group\"\x00\x12^\n\nListAdmins\x12&.org.couchers.api.groups.ListAdminsReq\x1a&.org.couchers.api.groups.ListAdminsRes\"\x00\x12\x61\n\x0bListMembers\x12\'.org.couchers.api.groups.ListMembersReq\x1a\'.org.couchers.api.groups.ListMembersRes\"\x00\x12^\n\nListPlaces\x12&.org.couchers.api.groups.ListPlacesReq\x1a&.org.couchers.api.groups.ListPlacesRes\"\x00\x12^\n\nListGuides\x12&.org.couchers.api.groups.ListGuidesReq\x1a&.org.couchers.api.groups.ListGuidesRes\"\x00\x12^\n\nListEvents\x12&.org.couchers.api.groups.ListEventsReq\x1a&.org.couchers.api.groups.ListEventsRes\"\x00\x12m\n\x0fListDiscussions\x12+.org.couchers.api.groups.ListDiscussionsReq\x1a+.org.couchers.api.groups.ListDiscussionsRes\"\x00\x12L\n\tJoinGroup\x12%.org.couchers.api.groups.JoinGroupReq\x1a\x16.google.protobuf.Empty\"\x00\x12N\n\nLeaveGroup\x12&.org.couchers.api.groups.LeaveGroupReq\x1a\x16.google.protobuf.Empty\"\x00\x12j\n\x0eListUserGroups\x12*.org.couchers.api.groups.ListUserGroupsReq\x1a*.org.couchers.api.groups.ListUserGroupsRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,discussions__pb2.DESCRIPTOR,events__pb2.DESCRIPTOR,pages__pb2.DESCRIPTOR,])




_COMMUNITYPARENT = _descriptor.Descriptor(
  name='CommunityParent',
  full_name='org.couchers.api.groups.CommunityParent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='community_id', full_name='org.couchers.api.groups.CommunityParent.community_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='org.couchers.api.groups.CommunityParent.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slug', full_name='org.couchers.api.groups.CommunityParent.slug', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='org.couchers.api.groups.CommunityParent.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=168,
  serialized_end=256,
)


_GROUPPARENT = _descriptor.Descriptor(
  name='GroupParent',
  full_name='org.couchers.api.groups.GroupParent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='org.couchers.api.groups.GroupParent.group_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='org.couchers.api.groups.GroupParent.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slug', full_name='org.couchers.api.groups.GroupParent.slug', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='org.couchers.api.groups.GroupParent.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=258,
  serialized_end=338,
)


_PARENT = _descriptor.Descriptor(
  name='Parent',
  full_name='org.couchers.api.groups.Parent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='community', full_name='org.couchers.api.groups.Parent.community', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group', full_name='org.couchers.api.groups.Parent.group', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='parent', full_name='org.couchers.api.groups.Parent.parent',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=341,
  serialized_end=477,
)


_GROUP = _descriptor.Descriptor(
  name='Group',
  full_name='org.couchers.api.groups.Group',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='org.couchers.api.groups.Group.group_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='org.couchers.api.groups.Group.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slug', full_name='org.couchers.api.groups.Group.slug', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='org.couchers.api.groups.Group.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='org.couchers.api.groups.Group.created', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parents', full_name='org.couchers.api.groups.Group.parents', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='main_page', full_name='org.couchers.api.groups.Group.main_page', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member', full_name='org.couchers.api.groups.Group.member', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin', full_name='org.couchers.api.groups.Group.admin', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member_count', full_name='org.couchers.api.groups.Group.member_count', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin_count', full_name='org.couchers.api.groups.Group.admin_count', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_moderate', full_name='org.couchers.api.groups.Group.can_moderate', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=480,
  serialized_end=794,
)


_GETGROUPREQ = _descriptor.Descriptor(
  name='GetGroupReq',
  full_name='org.couchers.api.groups.GetGroupReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='org.couchers.api.groups.GetGroupReq.group_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=796,
  serialized_end=827,
)


_LISTADMINSREQ = _descriptor.Descriptor(
  name='ListAdminsReq',
  full_name='org.couchers.api.groups.ListAdminsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='org.couchers.api.groups.ListAdminsReq.group_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.groups.ListAdminsReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.groups.ListAdminsReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=829,
  serialized_end=901,
)


_LISTADMINSRES = _descriptor.Descriptor(
  name='ListAdminsRes',
  full_name='org.couchers.api.groups.ListAdminsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='admin_user_ids', full_name='org.couchers.api.groups.ListAdminsRes.admin_user_ids', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.groups.ListAdminsRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=903,
  serialized_end=967,
)


_LISTMEMBERSREQ = _descriptor.Descriptor(
  name='ListMembersReq',
  full_name='org.couchers.api.groups.ListMembersReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='org.couchers.api.groups.ListMembersReq.group_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.groups.ListMembersReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.groups.ListMembersReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=969,
  serialized_end=1042,
)


_LISTMEMBERSRES = _descriptor.Descriptor(
  name='ListMembersRes',
  full_name='org.couchers.api.groups.ListMembersRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_user_ids', full_name='org.couchers.api.groups.ListMembersRes.member_user_ids', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.groups.ListMembersRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1044,
  serialized_end=1110,
)


_LISTPLACESREQ = _descriptor.Descriptor(
  name='ListPlacesReq',
  full_name='org.couchers.api.groups.ListPlacesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='org.couchers.api.groups.ListPlacesReq.group_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.groups.ListPlacesReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.groups.ListPlacesReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1112,
  serialized_end=1184,
)


_LISTPLACESRES = _descriptor.Descriptor(
  name='ListPlacesRes',
  full_name='org.couchers.api.groups.ListPlacesRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='places', full_name='org.couchers.api.groups.ListPlacesRes.places', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.groups.ListPlacesRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1186,
  serialized_end=1272,
)


_LISTGUIDESREQ = _descriptor.Descriptor(
  name='ListGuidesReq',
  full_name='org.couchers.api.groups.ListGuidesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='org.couchers.api.groups.ListGuidesReq.group_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.groups.ListGuidesReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.groups.ListGuidesReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1274,
  serialized_end=1346,
)


_LISTGUIDESRES = _descriptor.Descriptor(
  name='ListGuidesRes',
  full_name='org.couchers.api.groups.ListGuidesRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='guides', full_name='org.couchers.api.groups.ListGuidesRes.guides', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.groups.ListGuidesRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1348,
  serialized_end=1434,
)


_LISTEVENTSREQ = _descriptor.Descriptor(
  name='ListEventsReq',
  full_name='org.couchers.api.groups.ListEventsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='org.couchers.api.groups.ListEventsReq.group_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='past', full_name='org.couchers.api.groups.ListEventsReq.past', index=1,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.groups.ListEventsReq.page_size', index=2,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.groups.ListEventsReq.page_token', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1436,
  serialized_end=1522,
)


_LISTEVENTSRES = _descriptor.Descriptor(
  name='ListEventsRes',
  full_name='org.couchers.api.groups.ListEventsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='org.couchers.api.groups.ListEventsRes.events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.groups.ListEventsRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1524,
  serialized_end=1612,
)


_LISTDISCUSSIONSREQ = _descriptor.Descriptor(
  name='ListDiscussionsReq',
  full_name='org.couchers.api.groups.ListDiscussionsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='org.couchers.api.groups.ListDiscussionsReq.group_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.groups.ListDiscussionsReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.groups.ListDiscussionsReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1614,
  serialized_end=1691,
)


_LISTDISCUSSIONSRES = _descriptor.Descriptor(
  name='ListDiscussionsRes',
  full_name='org.couchers.api.groups.ListDiscussionsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='discussions', full_name='org.couchers.api.groups.ListDiscussionsRes.discussions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.groups.ListDiscussionsRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1693,
  serialized_end=1801,
)


_JOINGROUPREQ = _descriptor.Descriptor(
  name='JoinGroupReq',
  full_name='org.couchers.api.groups.JoinGroupReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='org.couchers.api.groups.JoinGroupReq.group_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1803,
  serialized_end=1835,
)


_LEAVEGROUPREQ = _descriptor.Descriptor(
  name='LeaveGroupReq',
  full_name='org.couchers.api.groups.LeaveGroupReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='org.couchers.api.groups.LeaveGroupReq.group_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1837,
  serialized_end=1870,
)


_LISTUSERGROUPSREQ = _descriptor.Descriptor(
  name='ListUserGroupsReq',
  full_name='org.couchers.api.groups.ListUserGroupsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='org.couchers.api.groups.ListUserGroupsReq.user_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.groups.ListUserGroupsReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.groups.ListUserGroupsReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1872,
  serialized_end=1947,
)


_LISTUSERGROUPSRES = _descriptor.Descriptor(
  name='ListUserGroupsRes',
  full_name='org.couchers.api.groups.ListUserGroupsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='org.couchers.api.groups.ListUserGroupsRes.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.groups.ListUserGroupsRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1949,
  serialized_end=2041,
)

_PARENT.fields_by_name['community'].message_type = _COMMUNITYPARENT
_PARENT.fields_by_name['group'].message_type = _GROUPPARENT
_PARENT.oneofs_by_name['parent'].fields.append(
  _PARENT.fields_by_name['community'])
_PARENT.fields_by_name['community'].containing_oneof = _PARENT.oneofs_by_name['parent']
_PARENT.oneofs_by_name['parent'].fields.append(
  _PARENT.fields_by_name['group'])
_PARENT.fields_by_name['group'].containing_oneof = _PARENT.oneofs_by_name['parent']
_GROUP.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GROUP.fields_by_name['parents'].message_type = _PARENT
_GROUP.fields_by_name['main_page'].message_type = pages__pb2._PAGE
_LISTPLACESRES.fields_by_name['places'].message_type = pages__pb2._PAGE
_LISTGUIDESRES.fields_by_name['guides'].message_type = pages__pb2._PAGE
_LISTEVENTSRES.fields_by_name['events'].message_type = events__pb2._EVENT
_LISTDISCUSSIONSRES.fields_by_name['discussions'].message_type = discussions__pb2._DISCUSSION
_LISTUSERGROUPSRES.fields_by_name['groups'].message_type = _GROUP
DESCRIPTOR.message_types_by_name['CommunityParent'] = _COMMUNITYPARENT
DESCRIPTOR.message_types_by_name['GroupParent'] = _GROUPPARENT
DESCRIPTOR.message_types_by_name['Parent'] = _PARENT
DESCRIPTOR.message_types_by_name['Group'] = _GROUP
DESCRIPTOR.message_types_by_name['GetGroupReq'] = _GETGROUPREQ
DESCRIPTOR.message_types_by_name['ListAdminsReq'] = _LISTADMINSREQ
DESCRIPTOR.message_types_by_name['ListAdminsRes'] = _LISTADMINSRES
DESCRIPTOR.message_types_by_name['ListMembersReq'] = _LISTMEMBERSREQ
DESCRIPTOR.message_types_by_name['ListMembersRes'] = _LISTMEMBERSRES
DESCRIPTOR.message_types_by_name['ListPlacesReq'] = _LISTPLACESREQ
DESCRIPTOR.message_types_by_name['ListPlacesRes'] = _LISTPLACESRES
DESCRIPTOR.message_types_by_name['ListGuidesReq'] = _LISTGUIDESREQ
DESCRIPTOR.message_types_by_name['ListGuidesRes'] = _LISTGUIDESRES
DESCRIPTOR.message_types_by_name['ListEventsReq'] = _LISTEVENTSREQ
DESCRIPTOR.message_types_by_name['ListEventsRes'] = _LISTEVENTSRES
DESCRIPTOR.message_types_by_name['ListDiscussionsReq'] = _LISTDISCUSSIONSREQ
DESCRIPTOR.message_types_by_name['ListDiscussionsRes'] = _LISTDISCUSSIONSRES
DESCRIPTOR.message_types_by_name['JoinGroupReq'] = _JOINGROUPREQ
DESCRIPTOR.message_types_by_name['LeaveGroupReq'] = _LEAVEGROUPREQ
DESCRIPTOR.message_types_by_name['ListUserGroupsReq'] = _LISTUSERGROUPSREQ
DESCRIPTOR.message_types_by_name['ListUserGroupsRes'] = _LISTUSERGROUPSRES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CommunityParent = _reflection.GeneratedProtocolMessageType('CommunityParent', (_message.Message,), {
  'DESCRIPTOR' : _COMMUNITYPARENT,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.CommunityParent)
  })
_sym_db.RegisterMessage(CommunityParent)

GroupParent = _reflection.GeneratedProtocolMessageType('GroupParent', (_message.Message,), {
  'DESCRIPTOR' : _GROUPPARENT,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.GroupParent)
  })
_sym_db.RegisterMessage(GroupParent)

Parent = _reflection.GeneratedProtocolMessageType('Parent', (_message.Message,), {
  'DESCRIPTOR' : _PARENT,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.Parent)
  })
_sym_db.RegisterMessage(Parent)

Group = _reflection.GeneratedProtocolMessageType('Group', (_message.Message,), {
  'DESCRIPTOR' : _GROUP,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.Group)
  })
_sym_db.RegisterMessage(Group)

GetGroupReq = _reflection.GeneratedProtocolMessageType('GetGroupReq', (_message.Message,), {
  'DESCRIPTOR' : _GETGROUPREQ,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.GetGroupReq)
  })
_sym_db.RegisterMessage(GetGroupReq)

ListAdminsReq = _reflection.GeneratedProtocolMessageType('ListAdminsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTADMINSREQ,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.ListAdminsReq)
  })
_sym_db.RegisterMessage(ListAdminsReq)

ListAdminsRes = _reflection.GeneratedProtocolMessageType('ListAdminsRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTADMINSRES,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.ListAdminsRes)
  })
_sym_db.RegisterMessage(ListAdminsRes)

ListMembersReq = _reflection.GeneratedProtocolMessageType('ListMembersReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTMEMBERSREQ,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.ListMembersReq)
  })
_sym_db.RegisterMessage(ListMembersReq)

ListMembersRes = _reflection.GeneratedProtocolMessageType('ListMembersRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTMEMBERSRES,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.ListMembersRes)
  })
_sym_db.RegisterMessage(ListMembersRes)

ListPlacesReq = _reflection.GeneratedProtocolMessageType('ListPlacesReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLACESREQ,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.ListPlacesReq)
  })
_sym_db.RegisterMessage(ListPlacesReq)

ListPlacesRes = _reflection.GeneratedProtocolMessageType('ListPlacesRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLACESRES,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.ListPlacesRes)
  })
_sym_db.RegisterMessage(ListPlacesRes)

ListGuidesReq = _reflection.GeneratedProtocolMessageType('ListGuidesReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTGUIDESREQ,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.ListGuidesReq)
  })
_sym_db.RegisterMessage(ListGuidesReq)

ListGuidesRes = _reflection.GeneratedProtocolMessageType('ListGuidesRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTGUIDESRES,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.ListGuidesRes)
  })
_sym_db.RegisterMessage(ListGuidesRes)

ListEventsReq = _reflection.GeneratedProtocolMessageType('ListEventsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTSREQ,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.ListEventsReq)
  })
_sym_db.RegisterMessage(ListEventsReq)

ListEventsRes = _reflection.GeneratedProtocolMessageType('ListEventsRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTSRES,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.ListEventsRes)
  })
_sym_db.RegisterMessage(ListEventsRes)

ListDiscussionsReq = _reflection.GeneratedProtocolMessageType('ListDiscussionsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTDISCUSSIONSREQ,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.ListDiscussionsReq)
  })
_sym_db.RegisterMessage(ListDiscussionsReq)

ListDiscussionsRes = _reflection.GeneratedProtocolMessageType('ListDiscussionsRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTDISCUSSIONSRES,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.ListDiscussionsRes)
  })
_sym_db.RegisterMessage(ListDiscussionsRes)

JoinGroupReq = _reflection.GeneratedProtocolMessageType('JoinGroupReq', (_message.Message,), {
  'DESCRIPTOR' : _JOINGROUPREQ,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.JoinGroupReq)
  })
_sym_db.RegisterMessage(JoinGroupReq)

LeaveGroupReq = _reflection.GeneratedProtocolMessageType('LeaveGroupReq', (_message.Message,), {
  'DESCRIPTOR' : _LEAVEGROUPREQ,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.LeaveGroupReq)
  })
_sym_db.RegisterMessage(LeaveGroupReq)

ListUserGroupsReq = _reflection.GeneratedProtocolMessageType('ListUserGroupsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERGROUPSREQ,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.ListUserGroupsReq)
  })
_sym_db.RegisterMessage(ListUserGroupsReq)

ListUserGroupsRes = _reflection.GeneratedProtocolMessageType('ListUserGroupsRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERGROUPSRES,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.groups.ListUserGroupsRes)
  })
_sym_db.RegisterMessage(ListUserGroupsRes)



_GROUPS = _descriptor.ServiceDescriptor(
  name='Groups',
  full_name='org.couchers.api.groups.Groups',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\003',
  create_key=_descriptor._internal_create_key,
  serialized_start=2044,
  serialized_end=3002,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetGroup',
    full_name='org.couchers.api.groups.Groups.GetGroup',
    index=0,
    containing_service=None,
    input_type=_GETGROUPREQ,
    output_type=_GROUP,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAdmins',
    full_name='org.couchers.api.groups.Groups.ListAdmins',
    index=1,
    containing_service=None,
    input_type=_LISTADMINSREQ,
    output_type=_LISTADMINSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMembers',
    full_name='org.couchers.api.groups.Groups.ListMembers',
    index=2,
    containing_service=None,
    input_type=_LISTMEMBERSREQ,
    output_type=_LISTMEMBERSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPlaces',
    full_name='org.couchers.api.groups.Groups.ListPlaces',
    index=3,
    containing_service=None,
    input_type=_LISTPLACESREQ,
    output_type=_LISTPLACESRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListGuides',
    full_name='org.couchers.api.groups.Groups.ListGuides',
    index=4,
    containing_service=None,
    input_type=_LISTGUIDESREQ,
    output_type=_LISTGUIDESRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListEvents',
    full_name='org.couchers.api.groups.Groups.ListEvents',
    index=5,
    containing_service=None,
    input_type=_LISTEVENTSREQ,
    output_type=_LISTEVENTSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDiscussions',
    full_name='org.couchers.api.groups.Groups.ListDiscussions',
    index=6,
    containing_service=None,
    input_type=_LISTDISCUSSIONSREQ,
    output_type=_LISTDISCUSSIONSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='JoinGroup',
    full_name='org.couchers.api.groups.Groups.JoinGroup',
    index=7,
    containing_service=None,
    input_type=_JOINGROUPREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LeaveGroup',
    full_name='org.couchers.api.groups.Groups.LeaveGroup',
    index=8,
    containing_service=None,
    input_type=_LEAVEGROUPREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListUserGroups',
    full_name='org.couchers.api.groups.Groups.ListUserGroups',
    index=9,
    containing_service=None,
    input_type=_LISTUSERGROUPSREQ,
    output_type=_LISTUSERGROUPSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_GROUPS)

DESCRIPTOR.services_by_name['Groups'] = _GROUPS

# @@protoc_insertion_point(module_scope)
